@@ -3,7 +3,8 @@ package js
 import (
 	"math/rand"
 	"net"
-	"github.com/bettercap/bettercap/network"
+
+	"github.com/bettercap/bettercap/v2/network"
 )
 
 type randomPackage struct {
@@ -23,4 +24,4 @@ func (c randomPackage) Mac() string {
 	hw := make([]byte, 6)
 	rand.Read(hw)
 	return network.NormalizeMac(net.HardwareAddr(hw).String())
-}
\ No newline at end of file
+}
